package com.chinaitop.depot.system.controller;

import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.depot.system.model.TMobileManager;
import com.chinaitop.depot.system.service.TMobileManagerService;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 移动端管理类
 * @author hf
 *
 */
@RestController
@RequestMapping(value="/depotMobile")
@Api(description = "移动端管理类")
public class DepotMobileController {
	
	@Autowired
	private TMobileManagerService tMobileManagerService;

	@Value("${web.upload-path}")
	private String uploadPath;

	/**
	 * 查找移动端信息
	 * @param pageNum	页码
	 * @param pageSize	每页条数
	 * @return
	 */
	@RequestMapping(value="/getMobileList", method = RequestMethod.GET)
	@ApiOperation(value="查找移动端信息", notes = "查找移动端信息列表，支持分页")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
			@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
			@ApiImplicitParam(name = "mobileName", value = "移动端名称", paramType = "query")
	})
	public PageInfo<TMobileManager> getMobileList(HttpServletRequest request, Integer pageNum, Integer pageSize,
    	String mobileName) {
		
		if (pageNum!=null && pageSize!=null) {
			PageHelper.startPage(pageNum, pageSize);
		}
		
		HashMap<String, Object> map = new HashMap<String, Object>();
		map.put("mobileName", mobileName);
		List<TMobileManager> listAll=tMobileManagerService.queryByExample(map);
		PageInfo<TMobileManager> pageInfo = new PageInfo<TMobileManager>(listAll);
		return pageInfo;
	}

	/**
	 * 验证移动端类型是否可用
	 * @param mobileType	移动端类型
	 * @param id	主键id
	 * @return
	 */
	@RequestMapping(value="/validMobileType", method = RequestMethod.GET)
	@ApiOperation(value="验证移动端类型", notes = "验证移动端类型是否可用")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "mobileType", value = "移动端类型", paramType = "query"),
			@ApiImplicitParam(name = "id", value = "主键id", paramType = "query")
	})
	public Boolean validMobileType(String mobileType,String id) {
		return tMobileManagerService.validMobileType(mobileType,id);
	}
	
	/**
	 * 根据主键id查找移动端信息
	 * @param id 主键id
	 * @return	TMobileManager	移动端信息
	 */
	@RequestMapping(value="/edit", method = RequestMethod.GET)
	@ApiOperation(value="编辑移动端信息", notes = "编辑移动端信息，用于新增或者修改")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "id", value = "主键id", paramType = "query")
	})
	public TMobileManager edit(String id) {
		TMobileManager tMobileManager = new TMobileManager();
		if (id != null && !id.isEmpty()) {
			tMobileManager = tMobileManagerService.findById(id);
		}
		return tMobileManager;
	}

	/**
	 * 保存移动端信息
	 * @param tMobileManagerJson	移动端信息json字符串
	 * @return
	 * @throws JsonParseException
	 * @throws JsonMappingException
	 * @throws IOException
	 */
	@RequestMapping(value="/save", method = RequestMethod.POST)
	@ApiOperation(value="保存移动端信息", notes = "保存移动端信息，新增或者修改")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "tMobileManagerJson", value = "移动端信息JSON串", paramType = "form")
	})
	public Map<String, Object> save(String tMobileManagerJson) throws JsonParseException, JsonMappingException, IOException {
		Map<String, Object> modelMap = new HashMap<>();
		// JSON字符串转对象
		ObjectMapper mapper = new ObjectMapper();
		TMobileManager tMobileManager = (TMobileManager)mapper.readValue(tMobileManagerJson, TMobileManager.class);
		if(tMobileManager.getId() == null){
			String id = UUID.randomUUID().toString().replace("-", "");//动态生成32随机字符串
			tMobileManager.setId(id);
			tMobileManager.setCreateTime(new Date());
			tMobileManagerService.add(tMobileManager);
		}else{
			tMobileManager.setCreateTime(new Date());
			tMobileManagerService.update(tMobileManager);
		}
		modelMap.put("status", "success");
		return modelMap;
	}
	
	/**
	 * 根据主键删除移动端信息
	 * @param id	主键
	 * @return
	 */
	@RequestMapping(value="/remove", method = RequestMethod.POST)
	@ApiOperation(value="删除移动端信息", notes = "根据主键删除移动端信息")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "id", value = "主键id", paramType = "form")
	})
	public Map<String, Object> remove(String id) {
		Map<String, Object> modelMap = new HashMap<>();
		if (id != null && !id.isEmpty()) {
			tMobileManagerService.remove(id);
		}
		modelMap.put("status", "success");
		return modelMap;
	}
	
	/**
     * 文件下载
     * 
     * @param filePath
     * @param response
     * @throws IOException
     */
	@RequestMapping(value="/download", method = RequestMethod.POST)
    public void download(String filePath, HttpServletRequest request, HttpServletResponse response) throws IOException {
		File file = new File(uploadPath + filePath);
        // 取得文件名。
        String fileName = file.getName();
        // 以流的形式下载文件。
        response.setHeader("content-type", "application/octet-stream");
        //response.setContentType("application/octet-stream");
        response.setContentType("application/vnd.android.package-archive");
        response.setHeader("Content-Disposition", "attachment;filename=" + 
                new String(fileName.getBytes("GB2312"), "ISO8859-1"));
        byte[] buff = new byte[1024];
        BufferedInputStream bis = null;
        OutputStream os = null;
        try {
            os = response.getOutputStream();
            bis = new BufferedInputStream(new FileInputStream(file));
            int i = 0;
            while ((i = bis.read(buff)) != -1) {
                os.write(buff, 0, i);
                /*i = bis.read(buff);*/
            }
            os.flush();
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
           bis.close();
           os.close();
           
        }
    }
	
}
